
# Hierarichcial Bayesian Target Encoder
`hierarchical-bay-cat-encoder` is a Python library for encoding classes of cross features derived from categorical features that relate to one another in a herarchival structure. It facilitates the process of converting categorical features into continuous variables based on the information with respect to target responses, a data preprocessing practice that often improves model performnace in machine learning and is one of well adopted winner techiniques in Kaggle competitions for tabular/structured data.



[![license](https://img.shields.io/badge/license-MIT-blue.svg)](/LICENSE)
![python version](https://img.shields.io/badge/python-3.6%2C3.7%2C3.8-blue?logo=python)




# Feedback
Comments and suggestions are welcome and appreciated. They can be sent to
lipin.juan02@gmail.com.

